@@ -7,7 +7,7 @@ use warnings;
 # attempts to move the specified attributes of the symbol to the output YAML
 # file.
 
-use YAML::XS qw(LoadFile DumpFile);
+use YAML::CacheLoader qw(LoadFile DumpFile);
 use Data::Dumper;
 use Getopt::Long;
 use File::Basename;
